Contributing — Scikit-HEP 0.0.1 documentation

# Contributing

If you already have an idea for a feature you’d like to see in scikit-hep, you can start by seeing how to contribute code. If not, we have plenty of ideas we’d love to see materialising!

BTW, check also the affiliated packages as your must-have feature could already exist there ...

## Contributing code

The Scikit-HEP project is community-driven and community-oriented. As such, we welcome contributions and contributors from all horizons, provided they comply with the Python Community Code of Conduct.

### Coding guidelines

Guidelines for coding and documentation are under development.

## Suggesting new functionality

First check that the functionality does not already exist in the API.

## Project ideas

A dedicated page is available as a forum for project ideas.

## Feedback and bug reporting

For now please provide feedback and/or report bugs via the Scikit-HEP GitHub Issues page.